import { Column, DefaultPlatform, ForeignKey, Sql, Table, TableDiff } from '@deepkit/sql';
import { ReflectionClass, ReflectionProperty, Serializer, Type } from '@deepkit/type';
import { SQLiteSchemaParser } from './sqlite-schema-parser.js';
import { SQLiteFilterBuilder } from './sql-filter-builder.sqlite.js';
import { MigrateOptions } from '@deepkit/orm';
export declare function isJsonLike(type: Type): boolean;
export declare class SQLitePlatform extends DefaultPlatform {
    protected defaultSqlType: string;
    protected annotationId: string;
    schemaParserType: typeof SQLiteSchemaParser;
    protected defaultNowExpression: string;
    readonly serializer: Serializer;
    constructor();
    quoteValue(value: any): string;
    applyLimitAndOffset(sql: Sql, limit?: number, offset?: number): void;
    createSqlFilterBuilder(schema: ReflectionClass<any>, tableName: string): SQLiteFilterBuilder;
    getDeepColumnAccessor(table: string, column: string, path: string): string;
    getModifyTableDDL(diff: TableDiff, options: MigrateOptions): string[];
    protected getMigrationTableDDL(diff: TableDiff, options: MigrateOptions): string[];
    protected setColumnType(column: Column, typeProperty: ReflectionProperty): void;
    /**
     * Unfortunately, SQLite does not support composite pks where one is AUTOINCREMENT,
     * so we have to flag both as NOT NULL and create in either way a UNIQUE constraint over pks since
     * those UNIQUE is otherwise automatically created by the sqlite engine.
     */
    normalizeTables(tables: Table[]): void;
    supportsInlinePrimaryKey(): boolean;
    getSchemaDelimiter(): string;
    getBeginDDL(): string;
    getEndDDL(): string;
    getAutoIncrement(): string;
    getColumnDDL(column: Column): string;
    getForeignKeyDDL(foreignKey: ForeignKey): string;
}
